==> haskell-vector-0.12.0.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vector.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector
version: 0.12.0.1
id: vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
key: vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
license: BSD3
copyright: (c) Roman Leshchinskiy 2008-2012
maintainer: Haskell Libraries Team <libraries@haskell.org>
homepage: https://github.com/haskell/vector
synopsis: Efficient Arrays
description:
    .
    An efficient implementation of Int-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>
category: Data, Data Structures
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
exposed: True
indefinite: False
exposed-modules:
    Data.Vector Data.Vector.Fusion.Bundle
    Data.Vector.Fusion.Bundle.Monadic Data.Vector.Fusion.Bundle.Size
    Data.Vector.Fusion.Stream.Monadic Data.Vector.Fusion.Util
    Data.Vector.Generic Data.Vector.Generic.Base
    Data.Vector.Generic.Mutable Data.Vector.Generic.Mutable.Base
    Data.Vector.Generic.New Data.Vector.Internal.Check
    Data.Vector.Mutable Data.Vector.Primitive
    Data.Vector.Primitive.Mutable Data.Vector.Storable
    Data.Vector.Storable.Internal Data.Vector.Storable.Mutable
    Data.Vector.Unboxed Data.Vector.Unboxed.Base
    Data.Vector.Unboxed.Mutable
abi: d8375a46a4155c3f449ce3d319b3dbaa
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/vector-0.12.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/vector-0.12.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/vector-0.12.0.1
hs-libraries: HSvector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
include-dirs: /usr/lib/ghc-8.2.2/site-local/vector-0.12.0.1/include
depends:
    base-4.10.1.0 primitive-0.6.2.0-EI3NK1Xfv9zEcRtyXK2EwZ
    ghc-prim-0.5.1.1 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             primitive-0.6.2.0-EI3NK1Xfv9zEcRtyXK2EwZ=8f45321f6a36e57e226bf2d17d6dafd0
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html: /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-0.12.0.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vector.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector
version: 0.12.0.1
id: vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
key: vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
license: BSD3
copyright: (c) Roman Leshchinskiy 2008-2012
maintainer: Haskell Libraries Team <libraries@haskell.org>
homepage: https://github.com/haskell/vector
synopsis: Efficient Arrays
description:
    .
    An efficient implementation of Int-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>
category: Data, Data Structures
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
exposed: True
indefinite: False
exposed-modules:
    Data.Vector Data.Vector.Fusion.Bundle
    Data.Vector.Fusion.Bundle.Monadic Data.Vector.Fusion.Bundle.Size
    Data.Vector.Fusion.Stream.Monadic Data.Vector.Fusion.Util
    Data.Vector.Generic Data.Vector.Generic.Base
    Data.Vector.Generic.Mutable Data.Vector.Generic.Mutable.Base
    Data.Vector.Generic.New Data.Vector.Internal.Check
    Data.Vector.Mutable Data.Vector.Primitive
    Data.Vector.Primitive.Mutable Data.Vector.Storable
    Data.Vector.Storable.Internal Data.Vector.Storable.Mutable
    Data.Vector.Unboxed Data.Vector.Unboxed.Base
    Data.Vector.Unboxed.Mutable
abi: 137c9db50bf637e10c6e6dd9e685ce59
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/vector-0.12.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/vector-0.12.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/vector-0.12.0.1
hs-libraries: HSvector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
include-dirs: /usr/lib/ghc-8.2.2/site-local/vector-0.12.0.1/include
depends:
    base-4.10.1.0 primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo
    ghc-prim-0.5.1.1 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=b4457a9f891c4eea587ee58a79b7f0fc
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html: /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
